aboutsummaryrefslogtreecommitdiff
path: root/lib/cmyth/include/debug.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/cmyth/include/debug.h')
-rw-r--r--lib/cmyth/include/debug.h16
1 files changed, 8 insertions, 8 deletions
diff --git a/lib/cmyth/include/debug.h b/lib/cmyth/include/debug.h
index 805964b2e0..e10a5cee44 100644
--- a/lib/cmyth/include/debug.h
+++ b/lib/cmyth/include/debug.h
@@ -2,8 +2,8 @@
* A C library for generating and controlling debug output
*/
-#ifndef __MVP_DEBUG_H
-#define __MVP_DEBUG_H
+#ifndef __CMYTH_DEBUG_H
+#define __CMYTH_DEBUG_H
#include <stdio.h>
#include <stdarg.h>
@@ -13,16 +13,16 @@ typedef struct {
int cur_level;
int (*selector)(int plevel, int slevel);
void (*msg_callback)(int level, char *msg);
-} mvp_debug_ctx_t;
+} cmyth_debug_ctx_t;
/**
* Make a static initializer for an mvp_debug_ctx_t which provides a debug
* context for a subsystem. This is a macro.
* \param n subsystem name (a static string is fine)
* \param l initial debug level for the subsystem
* \param s custom selector function pointer (NULL is okay)
*/
-#define MVP_DEBUG_CTX_INIT(n,l,s) { n, l, s, NULL }
+#define CMYTH_DEBUG_CTX_INIT(n,l,s) { n, l, s, NULL }
/**
* Set the debug level to be used for the subsystem
@@ -31,7 +31,7 @@ typedef struct {
* \return an integer subsystem id used for future interaction
*/
static inline void
-mvp_dbg_setlevel(mvp_debug_ctx_t *ctx, int level)
+__cmyth_dbg_setlevel(cmyth_debug_ctx_t *ctx, int level)
{
if (ctx != NULL) {
ctx->cur_level = level;
@@ -46,7 +46,7 @@ mvp_dbg_setlevel(mvp_debug_ctx_t *ctx, int level)
* \param ... arguments to the format
*/
static inline void
-mvp_dbg(mvp_debug_ctx_t *ctx, int level, char *fmt, va_list ap)
+__cmyth_dbg(cmyth_debug_ctx_t *ctx, int level, char *fmt, va_list ap)
{
char msg[4096];
int len;
@@ -65,4 +65,4 @@ mvp_dbg(mvp_debug_ctx_t *ctx, int level, char *fmt, va_list ap)
}
}
-#endif /* __MVP_DEBUG_H */
+#endif /* __CMYTH_DEBUG_H */
@@ -13,16 +13,16 @@ typedef struct {
/**
- * Make a static initializer for an mvp_debug_ctx_t which provides a debug
+ * Make a static initializer for an cmyth_debug_ctx_t which provides a debug
* context for a subsystem. This is a macro.
* \param n subsystem name (a static string is fine)